componenttools.get_improper_parentage_of_component_that_stop_with_component
===========================================================================

.. autofunction:: abjad.tools.componenttools.get_improper_parentage_of_component_that_stop_with_component.get_improper_parentage_of_component_that_stop_with_component
   :noindex:
